Diff
Modified: trunk/Source/WebCore/ChangeLog (175971 => 175972)
--- trunk/Source/WebCore/ChangeLog 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebCore/ChangeLog 2014-11-11 21:37:03 UTC (rev 175972)
@@ -1,5 +1,25 @@
2014-11-11 Myles C. Maxfield <[email protected]>
+ Finish moving CTFontGetVerticalGlyphsForCharacters and CTLineCreateWithUniCharProvider out from WKSI
+ https://bugs.webkit.org/show_bug.cgi?id=138623
+
+ Reviewed by Geoff Garen.
+
+ No new tests because there is no behavior change.
+
+ * WebCore.exp.in:
+ * WebCore.order:
+ * platform/graphics/mac/GlyphPageTreeNodeMac.cpp:
+ (WebCore::GlyphPage::fill):
+ * platform/graphics/mac/SimpleFontDataMac.mm:
+ (WebCore::SimpleFontData::canRenderCombiningCharacterSequence):
+ * platform/ios/WebCoreSystemInterfaceIOS.mm:
+ * platform/mac/WebCoreSystemInterface.h:
+ * platform/mac/WebCoreSystemInterface.mm:
+ * platform/spi/cocoa/CoreTextSPI.h:
+
+2014-11-11 Myles C. Maxfield <[email protected]>
+
Unreviewed Mountain Lion build fix
* platform/spi/cocoa/CoreTextSPI.h:
Modified: trunk/Source/WebCore/WebCore.exp.in (175971 => 175972)
--- trunk/Source/WebCore/WebCore.exp.in 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebCore/WebCore.exp.in 2014-11-11 21:37:03 UTC (rev 175972)
@@ -2156,8 +2156,6 @@
_wkCopyNSURLResponseCertificateChain
_wkCopyNSURLResponseStatusLine
_wkCopyRequestWithStorageSession
-_wkCreateCTLineWithUniCharProvider
-_wkCreateCTTypesetterWithUniCharProviderAndOptions
_wkCreatePrivateStorageSession
_wkDeleteAllHTTPCookies
_wkDeleteHTTPCookie
@@ -2451,7 +2449,6 @@
_wkGetNSEventKeyChar
_wkGetNSURLResponseCalculatedExpiration
_wkGetNSURLResponseMustRevalidate
-_wkGetVerticalGlyphsForCharacters
_wkGetWheelEventDeltas
_wkHitTestMediaUIPart
_wkMeasureMediaUIPart
@@ -2863,7 +2860,6 @@
_wkGetScreenSize
_wkGetUserAgent
_wkGetVendorNameForNavigator
-_wkGetVerticalGlyphsForCharacters
_wkIsGB18030ComplianceRequired
_wkIsOptimizedFullscreenSupported
_wkSetLayerContentsScale
Modified: trunk/Source/WebCore/WebCore.order (175971 => 175972)
--- trunk/Source/WebCore/WebCore.order 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebCore/WebCore.order 2014-11-11 21:37:03 UTC (rev 175972)
@@ -30589,9 +30589,6 @@
_wkSetCONNECTProxyForStream
_wkSetCONNECTProxyAuthorizationForStream
_wkCopyCONNECTProxyResponse
-_wkGetVerticalGlyphsForCharacters
-_wkCreateCTLineWithUniCharProvider
-_wkCreateCTTypesetterWithUniCharProviderAndOptions
_wkIOSurfaceContextCreate
_wkIOSurfaceContextCreateImage
_wkRecommendedScrollerStyle
Modified: trunk/Source/WebCore/platform/graphics/mac/GlyphPageTreeNodeMac.cpp (175971 => 175972)
--- trunk/Source/WebCore/platform/graphics/mac/SimpleFontDataMac.mm 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebCore/platform/graphics/mac/SimpleFontDataMac.mm 2014-11-11 21:37:03 UTC (rev 175972)
@@ -29,6 +29,7 @@
#import "BlockExceptions.h"
#import "Color.h"
+#import "CoreTextSPI.h"
#import "FloatRect.h"
#import "Font.h"
#import "FontCache.h"
@@ -492,7 +493,7 @@
RetainPtr<CGFontRef> cgFont = adoptCF(CTFontCopyGraphicsFont(platformData().ctFont(), 0));
ProviderInfo info = { characters, length, getCFStringAttributes(0, platformData().orientation()) };
- RetainPtr<CTLineRef> line = adoptCF(wkCreateCTLineWithUniCharProvider(&provideStringAndAttributes, 0, &info));
+ RetainPtr<CTLineRef> line = adoptCF(CTLineCreateWithUniCharProvider(&provideStringAndAttributes, 0, &info));
CFArrayRef runArray = CTLineGetGlyphRuns(line.get());
CFIndex runCount = CFArrayGetCount(runArray);
Modified: trunk/Source/WebCore/platform/ios/WebCoreSystemInterfaceIOS.mm (175971 => 175972)
--- trunk/Source/WebCore/platform/ios/WebCoreSystemInterfaceIOS.mm 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebCore/platform/ios/WebCoreSystemInterfaceIOS.mm 2014-11-11 21:37:03 UTC (rev 175972)
@@ -71,11 +71,6 @@
WEBCORE_EXPORT void (*wkSetRequestStorageSession)(CFURLStorageSessionRef, CFMutableURLRequestRef);
#endif
-WEBCORE_EXPORT bool (*wkGetVerticalGlyphsForCharacters)(CTFontRef, const UniChar[], CGGlyph[], size_t);
-WEBCORE_EXPORT CTLineRef (*wkCreateCTLineWithUniCharProvider)(const UniChar* (*provide)(CFIndex stringIndex, CFIndex* charCount, CFDictionaryRef* attributes, void*), void (*dispose)(const UniChar* chars, void*), void*);
-
-WEBCORE_EXPORT CTTypesetterRef (*wkCreateCTTypesetterWithUniCharProviderAndOptions)(const UniChar* (*provide)(CFIndex stringIndex, CFIndex* charCount, CFDictionaryRef* attributes, void*), void (*dispose)(const UniChar* chars, void*), void*, CFDictionaryRef options);
-
#if !PLATFORM(IOS_SIMULATOR)
WEBCORE_EXPORT CGContextRef (*wkIOSurfaceContextCreate)(IOSurfaceRef surface, unsigned width, unsigned height, CGColorSpaceRef colorSpace);
WEBCORE_EXPORT CGImageRef (*wkIOSurfaceContextCreateImage)(CGContextRef context);
Modified: trunk/Source/WebCore/platform/mac/WebCoreSystemInterface.h (175971 => 175972)
--- trunk/Source/WebCore/platform/mac/WebCoreSystemInterface.h 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebCore/platform/mac/WebCoreSystemInterface.h 2014-11-11 21:37:03 UTC (rev 175972)
@@ -226,18 +226,12 @@
extern void (*wkSetCONNECTProxyAuthorizationForStream)(CFReadStreamRef, CFStringRef proxyAuthorizationString);
extern CFHTTPMessageRef (*wkCopyCONNECTProxyResponse)(CFReadStreamRef, CFURLRef responseURL, CFStringRef proxyHost, CFNumberRef proxyPort);
-extern bool (*wkGetVerticalGlyphsForCharacters)(CTFontRef, const UniChar[], CGGlyph[], size_t);
-
extern BOOL (*wkUseSharedMediaUI)();
#if !PLATFORM(IOS)
extern void* wkGetHyphenationLocationBeforeIndex;
#endif
-extern CTLineRef (*wkCreateCTLineWithUniCharProvider)(const UniChar* (*provide)(CFIndex stringIndex, CFIndex* charCount, CFDictionaryRef* attributes, void*), void (*dispose)(const UniChar* chars, void*), void*);
-
-extern CTTypesetterRef (*wkCreateCTTypesetterWithUniCharProviderAndOptions)(const UniChar* (*provide)(CFIndex stringIndex, CFIndex* charCount, CFDictionaryRef* attributes, void*), void (*dispose)(const UniChar* chars, void*), void*, CFDictionaryRef options);
-
#if PLATFORM(COCOA) && USE(CA) && !PLATFORM(IOS_SIMULATOR)
extern CGContextRef (*wkIOSurfaceContextCreate)(IOSurfaceRef surface, unsigned width, unsigned height, CGColorSpaceRef colorSpace);
extern CGImageRef (*wkIOSurfaceContextCreateImage)(CGContextRef context);
Modified: trunk/Source/WebCore/platform/mac/WebCoreSystemInterface.mm (175971 => 175972)
--- trunk/Source/WebCore/platform/mac/WebCoreSystemInterface.mm 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebCore/platform/mac/WebCoreSystemInterface.mm 2014-11-11 21:37:03 UTC (rev 175972)
@@ -104,14 +104,8 @@
void (*wkSetRequestStorageSession)(CFURLStorageSessionRef, CFMutableURLRequestRef);
#endif
-bool (*wkGetVerticalGlyphsForCharacters)(CTFontRef, const UniChar[], CGGlyph[], size_t);
-
void* wkGetHyphenationLocationBeforeIndex;
-CTLineRef (*wkCreateCTLineWithUniCharProvider)(const UniChar* (*provide)(CFIndex stringIndex, CFIndex* charCount, CFDictionaryRef* attributes, void*), void (*dispose)(const UniChar* chars, void*), void*);
-
-CTTypesetterRef (*wkCreateCTTypesetterWithUniCharProviderAndOptions)(const UniChar* (*provide)(CFIndex stringIndex, CFIndex* charCount, CFDictionaryRef* attributes, void*), void (*dispose)(const UniChar* chars, void*), void*, CFDictionaryRef options);
-
CGContextRef (*wkIOSurfaceContextCreate)(IOSurfaceRef surface, unsigned width, unsigned height, CGColorSpaceRef colorSpace);
CGImageRef (*wkIOSurfaceContextCreateImage)(CGContextRef context);
Modified: trunk/Source/WebCore/platform/spi/cocoa/CoreTextSPI.h (175971 => 175972)
--- trunk/Source/WebCore/platform/spi/cocoa/CoreTextSPI.h 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebCore/platform/spi/cocoa/CoreTextSPI.h 2014-11-11 21:37:03 UTC (rev 175972)
@@ -50,6 +50,7 @@
CTLineRef CTLineCreateWithUniCharProvider(CTUniCharProviderCallback provide, CTUniCharDisposeCallback dispose, void* refCon);
CTTypesetterRef CTTypesetterCreateWithUniCharProviderAndOptions(CTUniCharProviderCallback provide, CTUniCharDisposeCallback dispose, void* refCon, CFDictionaryRef options);
bool CTFontTransformGlyphs(CTFontRef, CGGlyph glyphs[], CGSize advances[], CFIndex count, CTFontTransformOptions);
+bool CTFontGetVerticalGlyphsForCharacters(CTFontRef, const UniChar characters[], CGGlyph glyphs[], CFIndex count);
}
Modified: trunk/Source/WebKit/mac/ChangeLog (175971 => 175972)
--- trunk/Source/WebKit/mac/ChangeLog 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebKit/mac/ChangeLog 2014-11-11 21:37:03 UTC (rev 175972)
@@ -1,3 +1,14 @@
+2014-11-11 Myles C. Maxfield <[email protected]>
+
+ Finish moving CTFontGetVerticalGlyphsForCharacters and CTLineCreateWithUniCharProvider out from WKSI
+ https://bugs.webkit.org/show_bug.cgi?id=138623
+
+ Reviewed by Geoff Garen.
+
+ * WebCoreSupport/WebSystemInterface.mm:
+ (InitWebCoreSystemInterface):
+ * WebKit.order:
+
2014-11-11 Tim Horton <[email protected]>
Localize strings for action menus
Modified: trunk/Source/WebKit/mac/WebCoreSupport/WebSystemInterface.mm (175971 => 175972)
--- trunk/Source/WebKit/mac/WebCoreSupport/WebSystemInterface.mm 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebKit/mac/WebCoreSupport/WebSystemInterface.mm 2014-11-11 21:37:03 UTC (rev 175972)
@@ -120,7 +120,6 @@
INIT(QTClearMediaDownloadCache);
#endif
- INIT(GetVerticalGlyphsForCharacters);
#if PLATFORM(IOS)
INIT(ExecutableWasLinkedOnOrAfterIOSVersion);
INIT(GetDeviceClass);
@@ -132,13 +131,10 @@
INIT(GetMediaUIImageData);
#endif
- INIT(CreateCTLineWithUniCharProvider);
-
#if !PLATFORM(IOS_SIMULATOR)
INIT(IOSurfaceContextCreate);
INIT(IOSurfaceContextCreateImage);
#endif
- INIT(CreateCTTypesetterWithUniCharProviderAndOptions);
#if !PLATFORM(IOS)
INIT(RecommendedScrollerStyle);
INIT(ExecutableWasLinkedOnOrBeforeSnowLeopard);
Modified: trunk/Source/WebKit/mac/WebKit.order (175971 => 175972)
--- trunk/Source/WebKit/mac/WebKit.order 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebKit/mac/WebKit.order 2014-11-11 21:37:03 UTC (rev 175972)
@@ -733,7 +733,6 @@
_WKGetCFURLResponseMIMEType
__ZN20WebFrameLoaderClient38dispatchDidLoadResourceFromMemoryCacheEPN7WebCore14DocumentLoaderERKNS0_15ResourceRequestERKNS0_16ResourceResponseEi
-[WebFrame(WebInternal) _characterRangeAtPoint:]
-_WKCreateCTTypesetterWithUniCharProviderAndOptions
-[WebView(WebViewEditing) selectedDOMRange]
-[WebHTMLRepresentation attributedStringFrom:startOffset:to:endOffset:]
-[WebHTMLView shouldDelayWindowOrderingForEvent:]
@@ -1530,7 +1529,6 @@
-[WebBackForwardList addItem:]
__Z4coreP14WebHistoryItem
-[WebBackForwardList goToItem:]
-_WKCreateCTLineWithUniCharProvider
-[WebInspector show:]
-[WebInspector showWindow]
__ZN18WebInspectorClient21openInspectorFrontendEPN7WebCore19InspectorControllerE
@@ -2313,8 +2311,6 @@
-[WebHTMLView(WebNSTextInputSupport) selectedRange]
-[WebFrame(WebPrivate) _selectedNSRange]
-[WebFrameView _pageHorizontally:]
-_WKGetVerticalGlyphsForCharacters
-_CTFontGetVerticalGlyphsForCharacters
__ZThn8_N15WebEditorClient17getGuessesForWordERKN3WTF6StringES3_RNS0_6VectorIS1_Lm0ENS0_15CrashOnOverflowEEE
__ZN15WebEditorClient17getGuessesForWordERKN3WTF6StringES3_RNS0_6VectorIS1_Lm0ENS0_15CrashOnOverflowEEE
__ZN3WTF6VectorINS_6StringELm0ENS_15CrashOnOverflowEE14shrinkCapacityEm
Modified: trunk/Source/WebKit2/ChangeLog (175971 => 175972)
--- trunk/Source/WebKit2/ChangeLog 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebKit2/ChangeLog 2014-11-11 21:37:03 UTC (rev 175972)
@@ -1,3 +1,14 @@
+2014-11-11 Myles C. Maxfield <[email protected]>
+
+ Finish moving CTFontGetVerticalGlyphsForCharacters and CTLineCreateWithUniCharProvider out from WKSI
+ https://bugs.webkit.org/show_bug.cgi?id=138623
+
+ Reviewed by Geoff Garen.
+
+ * WebProcess/WebCoreSupport/mac/WebSystemInterface.mm:
+ (InitWebCoreSystemInterface):
+ * mac/WebKit2.order:
+
2014-11-11 Timothy Horton <[email protected]>
Add a respondsToSelector check to dismissActionMenuPopovers
Modified: trunk/Source/WebKit2/WebProcess/WebCoreSupport/mac/WebSystemInterface.mm (175971 => 175972)
--- trunk/Source/WebKit2/WebProcess/WebCoreSupport/mac/WebSystemInterface.mm 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebKit2/WebProcess/WebCoreSupport/mac/WebSystemInterface.mm 2014-11-11 21:37:03 UTC (rev 175972)
@@ -49,7 +49,6 @@
INIT(CopyCONNECTProxyResponse);
INIT(CopyNSURLResponseStatusLine);
INIT(CopyNSURLResponseCertificateChain);
- INIT(CreateCTLineWithUniCharProvider);
#if !PLATFORM(IOS)
INIT(DrawBezeledTextArea);
INIT(DrawCapsLockIndicator);
@@ -61,7 +60,6 @@
INIT(GetFontInLanguageForCharacter);
INIT(GetFontInLanguageForRange);
#endif
- INIT(GetVerticalGlyphsForCharacters);
INIT(GetHTTPRequestPriority);
INIT(GetNSURLResponseLastModifiedDate);
#if !PLATFORM(IOS)
@@ -128,7 +126,6 @@
INIT(IOSurfaceContextCreate);
INIT(IOSurfaceContextCreateImage);
#endif // !PLATFORM(IOS_SIMULATOR)
- INIT(CreateCTTypesetterWithUniCharProviderAndOptions);
#if !PLATFORM(IOS)
INIT(RecommendedScrollerStyle);
INIT(ExecutableWasLinkedOnOrBeforeSnowLeopard);
Modified: trunk/Source/WebKit2/mac/WebKit2.order (175971 => 175972)
--- trunk/Source/WebKit2/mac/WebKit2.order 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebKit2/mac/WebKit2.order 2014-11-11 21:37:03 UTC (rev 175972)
@@ -944,8 +944,6 @@
_WKPageCanGoForward
__ZNK6WebKit12WebPageProxy12canGoForwardEv
__ZN6WebKit18WebBackForwardList11forwardItemEv
-_WKCreateCTLineWithUniCharProvider
-_WKCreateCTTypesetterWithUniCharProviderAndOptions
_WKSetCGFontRenderingMode
-[WKView(Private) updateLayer]
-[WKView drawsBackground]
@@ -9141,8 +9139,6 @@
__ZN7CoreIPC13MessageSender4sendIN8Messages12WebPageProxy9TakeFocusEEEbRKT_y
__ZN6WebKit12WebPageProxy9takeFocusEj
__ZN6WebKit11WebUIClient9takeFocusEPNS_12WebPageProxyEj
-_WKGetVerticalGlyphsForCharacters
-_CTFontGetVerticalGlyphsForCharacters
__ZN6WebKit15WebChromeClient19customHighlightRectEPN7WebCore4NodeERKN3WTF12AtomicStringERKNS1_9FloatRectE
__ZN6WebKit15WebChromeClient20paintCustomHighlightEPN7WebCore4NodeERKN3WTF12AtomicStringERKNS1_9FloatRectESA_bb
_WKBundlePageFindString
--- trunk/Source/WebCore/platform/graphics/mac/GlyphPageTreeNodeMac.cpp 2014-11-11 21:21:45 UTC (rev 175971)
+++ trunk/Source/WebCore/platform/graphics/mac/GlyphPageTreeNodeMac.cpp 2014-11-11 21:37:03 UTC (rev 175972)
@@ -30,6 +30,7 @@
#include "GlyphPageTreeNode.h"
#include "CGFontUnicodeSupportSPI.h"
+#include "CoreTextSPI.h"
#include "Font.h"
#include "SimpleFontData.h"
#include "WebCoreSystemInterface.h"
@@ -83,9 +84,9 @@
haveGlyphs = true;
}
}
- } else if (!fontData->platformData().isCompositeFontReference() && ((fontData->platformData().widthVariant() == RegularWidth) ? wkGetVerticalGlyphsForCharacters(fontData->platformData().ctFont(), buffer, glyphs.data(), bufferLength)
+ } else if (!fontData->platformData().isCompositeFontReference() && ((fontData->platformData().widthVariant() == RegularWidth) ? CTFontGetVerticalGlyphsForCharacters(fontData->platformData().ctFont(), buffer, glyphs.data(), bufferLength)
: CTFontGetGlyphsForCharacters(fontData->platformData().ctFont(), buffer, glyphs.data(), bufferLength))) {
// When buffer consists of surrogate pairs, wkGetVerticalGlyphsForCharacters and CTFontGetGlyphsForCharacters
// place the glyphs at indices corresponding to the first character of each pair.
unsigned glyphStep = bufferLength / length;
for (unsigned i = 0; i < length; ++i) {
@@ -83,9 +84,9 @@
: CTFontGetGlyphsForCharacters(fontData->platformData().ctFont(), buffer, glyphs.data(), bufferLength))) {
- // When buffer consists of surrogate pairs, wkGetVerticalGlyphsForCharacters and CTFontGetGlyphsForCharacters
+ // When buffer consists of surrogate pairs, CTFontGetVerticalGlyphsForCharacters and CTFontGetGlyphsForCharacters
// place the glyphs at indices corresponding to the first character of each pair.
unsigned glyphStep = bufferLength / length;
Modified: trunk/Source/WebCore/platform/graphics/mac/SimpleFontDataMac.mm (175971 => 175972)